﻿using pdftron;
using pdftron.Common;
using pdftron.PDF;
using pdftron.SDF;

namespace PdfTronSample
{
    public class Program
    {
        private static PDFNetLoader loader = PDFNetLoader.Instance();

        public static void Main(string[] args)
        {
            PDFNet.Initialize("DIPS AS (dips.no):OEM:DIPS Arena::WL+:AMS(20231206):AEE55FB16A57EF5425A3D3AC4D06DC94C64F2D16FF676E2C84945CE5BBE25609B6F5C7");

            var bytes = PdfTronConvert();           
        }

        public static byte[] PdfTronConvert()
        {
            HTML2PDF.SetModulePath("binaries/PdfTron/HTML2PDFLinux");

            if (HTML2PDF.IsModuleAvailable())
            {
                Console.WriteLine("HTML2PDF Module was found");
            }

            try
            {
                using (PDFDoc doc = new PDFDoc())
                {
                    HTML2PDF converter = new HTML2PDF();

                    var html = File.ReadAllText("binaries/PdfTron/HTML2PDFLinux/sampleFormat7.txt");

                    converter.InsertFromHtmlString(html);
                    bool isConverted = converter.Convert(doc);

                    if (isConverted)
                    {
                        var bytes = doc.Save(SDFDoc.SaveOptions.e_linearized);
                        doc.Save("binaries/PdfTron/HTML2PDFLinux/output.pdf", SDFDoc.SaveOptions.e_linearized);

                        Console.WriteLine(@"Success");

                        return bytes;
                    }
                    else
                    {
                        Console.WriteLine("Conversion Failed");
                        throw new Exception(converter.GetLog());
                    }                        
                }
            }
            catch (PDFNetException e)
            {
                Console.WriteLine(e.Message);
                throw new Exception(e.Message);
            }
        }
    }
}